# rgevolve metapackage

## Install all rgevolve packages at once

`pip install rgevolve` installs the `rgevolve-core` package containing the core functionality and all available subpackages containing Renormalization Group Evolution matrices in various EFTs and bases.

This is an empty metapackage for user convenience.
